@@ -1,13 +1,4 @@
-/*  callback_func.c
- *
- *  Callback Functions
- */
-
 /*
- *  xwxapt: An application to decode APT signals from
- *  weather satellites and produce image(s) of the weather.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -21,7 +12,12 @@
  *  http://www.gnu.org/copyleft/gpl.txt
  */
 
+#ifndef CALLBACK_FUNC_H
+#define CALLBACK_FUNC_H     1
+
 #include <libgen.h>
+#include "common.h"
+#include "rtlsdr.h"
 
-/*------------------------------------------------------------------------*/
+#endif
 
