@@ -1,8 +1,4 @@
 /*
- *  xwxapt: An application to decode APT signals from weather
- *  satellites and produce an image of the weather.
- *
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public License as
  *  published by the Free Software Foundation; either version 2 of
@@ -17,11 +13,10 @@
  */
 
 #ifndef MAIN_H
-#define MAIN_H		1
+#define MAIN_H      1
 
-#include <unistd.h>
-#include <signal.h>
 #include "common.h"
+#include "ifft.h"
 #include "image.h"
 
 #endif
